@@ -279,7 +279,184 @@ class CustomDataset(Dataset):
                 pickle_file = open(info_save_path, 'wb')
                 pickle.dump(info_data, pickle_file)
                 pickle_file.close()
+
+
+class CustomDatasetV2(CustomDataset):
+    def __init__(self, images_dir, label_dir = None, device = None, normalizer = None, mode = 'train', dim = '3d', correct_direction = False, resample = None,
+                 patch_size = (128, 128, 128), transform = None, nifti = False):
+        
+        self.nifti = nifti
+        self.patch_size = np.array(patch_size)
+        self.transform = transform
+        self.batch_size = 1
+        super().__init__(device = device, normalizer = normalizer, mode = mode, dim = dim, correct_direction = correct_direction, resample = resample, root_dir = images_dir)
+
+        if self.nifti:
+            self.images_dir = images_dir
+            self.label_dir = label_dir
+            self.images_list = os.listdir(images_dir)
+            self.labels_list = os.listdir(label_dir)
+
+    def __len__(self):
+        return super().__len__()
+    
+    
+    def get_oversample_patch(self, images, seg):
+        if not isinstance(images, np.ndarray):
+            images = images.numpy()
+
+        if not isinstance(seg, np.ndarray):
+            seg = seg.numpy()
+
+        non_zero_coords = np.array(np.where(seg != 0))
+        shape_to_index = np.array(images[0].shape) - 1 
+        
+        oversample_high = np.clip(np.max(non_zero_coords, axis = 1) + 1, self.patch_size/2 - 1, shape_to_index - self.patch_size/2)
+        oversample_low = np.clip(np.min(non_zero_coords, axis = 1), self.patch_size/2 - 1, shape_to_index - self.patch_size/2)
+        oversample_center = np.random.randint(low = oversample_low, high = oversample_high + 1)
+
+        oversample_patch_upper_bound = oversample_center + (self.patch_size/2) + 1
+        oversample_patch_lower_bound = oversample_center - (self.patch_size/2 - 1)
+        oversample_patch_bound = np.concatenate((oversample_patch_lower_bound.reshape(-1,1),oversample_patch_upper_bound.reshape(-1,1)), axis = 1).astype(int)
+
+        oversample_patch_images = images[:, oversample_patch_bound[0][0] : oversample_patch_bound[0][1],
+                                          oversample_patch_bound[1][0] : oversample_patch_bound[1][1],
+                                          oversample_patch_bound[2][0] : oversample_patch_bound[2][1]]
+        oversample_patch_seg = seg[oversample_patch_bound[0][0] : oversample_patch_bound[0][1],
+                                          oversample_patch_bound[1][0] : oversample_patch_bound[1][1],
+                                          oversample_patch_bound[2][0] : oversample_patch_bound[2][1]]
+        
+        return np.expand_dims(oversample_patch_images , axis = 0), np.expand_dims(oversample_patch_seg , axis = 0)
+    
+    def get_normal_patch(self, images, seg):
+        if not isinstance(images, np.ndarray):
+            images = images.numpy()
+
+        if not isinstance(seg, np.ndarray):
+            seg = seg.numpy()
+
+        shape_to_index = np.array(images[0].shape) - 1 
+        normal_center = np.random.randint(low = self.patch_size/2 - 1, high = shape_to_index - (self.patch_size/2) + 1 )
+        normal_patch_upper_bound = normal_center + (self.patch_size/2) + 1
+        normal_patch_lower_bound = normal_center - (self.patch_size/2 - 1)
+        normal_patch_bound = np.concatenate((normal_patch_lower_bound.reshape(-1,1),normal_patch_upper_bound.reshape(-1,1)), axis = 1).astype(int)
+        normal_patch_images = images[:, normal_patch_bound[0][0] : normal_patch_bound[0][1],
+                                          normal_patch_bound[1][0] : normal_patch_bound[1][1],
+                                          normal_patch_bound[2][0] : normal_patch_bound[2][1]]
+        normal_patch_seg = seg[normal_patch_bound[0][0] : normal_patch_bound[0][1],
+                                          normal_patch_bound[1][0] : normal_patch_bound[1][1],
+                                          normal_patch_bound[2][0] : normal_patch_bound[2][1]]
+        
+        return np.expand_dims(normal_patch_images , axis = 0), np.expand_dims(normal_patch_seg , axis = 0)
+
+    
+    def pad_image_seg(self, images, seg): #patch size보다 전체 이미지 크기가 작을 경우 padding을 진행
+        if isinstance(images, np.ndarray):
+            images = torch.tensor(images.copy())
+        if isinstance(seg, np.ndarray):
+            seg = torch.tensor(seg.copy())
+        image_shape = np.array(images[0].shape)
+        if np.any(image_shape < self.patch_size):
+            odd_pad = ((self.patch_size - image_shape) % 2 != 0).astype(int)
+            even_pad = np.repeat(np.clip(((self.patch_size - image_shape)/2).astype(int), 0, np.inf), 2)
+            for i in range(len(odd_pad)):
+                even_pad[i*2] += odd_pad[i]
+            even_pad = tuple(even_pad[::-1].astype(int).copy())
+            images = F.pad(images, even_pad, "constant", 0 )
+            seg = F.pad(seg, even_pad, "constant", 0 )
+
+        return images, seg
+
+    def __getitem__(self, idx):
+        if self.nifti:
+            info_data = dict()
+            img = sitk.ReadImage(os.path.join(self.images_dir, self.images_list[idx]))
+            x = sitk.GetArrayFromImage(img)
+            info_data['spacing'] = img.GetSpacing()
+            info_data['direction'] = img.GetDirection()
+
+            if self.label_dir != None:
+                seg = sitk.ReadImage(os.path.join(self.label_dir, self.labels_list[idx]))
+                y = sitk.GetArrayFromImage(seg)
+        else:
+            info_file = open(os.path.join(self.root_dir,self.info_name[idx]), 'rb')
+            info_data = pickle.load(info_file)
+            info_file.close()
+            data = np.load(os.path.join(self.root_dir, self.image_name[idx]))
+            x = data['x']
+            y = data['y']
+
+        if len(x.shape) == 3 and self.dim == '3d':
+            #modality가 1개인 경우
+            x = np.expand_dims(x, axis = 0)
+        elif len(x.shape) == 2 and self.dim == '2d':
+            x = np.expand_dims(x, axis = 0)
+
+        if self.correct_direction:
+            for i in range(len(x)):
+                if i == 0:
+                    result = set_direction(x[i], info_data['direction']).unsqueeze(0)
+                else:
+                    result = torch.vstack((result, set_direction(x[i], info_data['direction']).unsqueeze(0)))
+            x = result 
+            if self.mode == 'train' :
+                y = set_direction(y, info_data['direction'])
+
+        if self.normalizer:
+            x = self.normalizer(x)
+        
+        
+        if self.resample != None:
+            if self.mode == 'train' :
+                if isinstance(x, np.ndarray):
+                    x = torch.tensor(x.copy())
+                if isinstance(y, np.ndarray):
+                    y = torch.tensor(y.copy())
+                result = self.resample(torch.vstack((x, y.unsqueeze(0))), info_data)
+                x = result[:-1]
+                y = result[-1].squeeze(0)
             
+            else:
+                x = self.resample(x, info_data)
+        
+        x, y = self.pad_image_seg(x, y)
+        if self.batch_size == 1 :
+            result_images, result_seg = self.get_normal_patch(x, y)
+
+
+        for i_b in range(self.batch_size//2):
+            oversample_images, oversample_seg = self.get_oversample_patch(x, y)
+            normal_images, normal_seg = self.get_normal_patch(x, y)
+
+            if i_b == 0:
+                result_images = np.concatenate((normal_images, oversample_images), axis = 0) #bs, n, x, y, z
+                result_seg = np.concatenate((normal_seg, oversample_seg), axis = 0) #bs, x, y, z
+            
+            else:
+                result_images = np.concatenate((result_images, oversample_images), axis = 0)
+                result_seg = np.concatenate((result_seg, oversample_seg), axis = 0)
+                result_images = np.concatenate((result_images, normal_images), axis = 0)
+                result_seg = np.concatenate((result_seg, normal_seg), axis = 0)
+
+
+        if isinstance(result_images, np.ndarray):
+            result_images = torch.tensor(result_images)
+        
+        if isinstance(result_seg, np.ndarray):
+            result_seg = torch.tensor(result_seg)
+        
+        if result_images.device.index != self.device:
+            result_images = result_images.to(self.device)
+
+        if result_seg.device.index != self.device:
+            result_seg = result_seg.to(self.device)
+
+        if self.transform:
+            result_images, result_seg = self.transform(result_images.to(self.device), result_seg.to(self.device), info_data)
+        
+        return result_images.squeeze(0), result_seg.squeeze(0).long(), info_data
+
+
 
 class Dataset2point5(CustomDataset):
     def __init__(self, root_dir, degree, device=None, normalizer=None, mode='train', dim='3d', correct_direction=True, resample=None):
@@ -629,163 +806,6 @@ class Interactive_DataLoader(DataLoader3D):
 
 
 
-class CustomDatasetV2(CustomDataset):
-    def __init__(self, root_dir, device = None, normalizer = None, mode = 'train', dim = '3d', correct_direction = False, resample = None,
-                 patch_size = (128, 128, 128), transform = None):
-        
-        self.patch_size = np.array(patch_size)
-        self.transform = transform
-        self.batch_size = 1
-        super().__init__(root_dir, device = device, normalizer = normalizer, mode = mode, dim = dim, correct_direction = correct_direction, resample = resample)
-    
-    def __len__(self):
-        return super().__len__()
-    
-    
-    def get_oversample_patch(self, images, seg):
-        if not isinstance(images, np.ndarray):
-            images = images.numpy()
-
-        if not isinstance(seg, np.ndarray):
-            seg = seg.numpy()
-
-        non_zero_coords = np.array(np.where(seg != 0))
-        shape_to_index = np.array(images[0].shape) - 1 
-        
-        oversample_high = np.clip(np.max(non_zero_coords, axis = 1) + 1, self.patch_size/2 - 1, shape_to_index - self.patch_size/2)
-        oversample_low = np.clip(np.min(non_zero_coords, axis = 1), self.patch_size/2 - 1, shape_to_index - self.patch_size/2)
-        oversample_center = np.random.randint(low = oversample_low, high = oversample_high + 1)
-
-        oversample_patch_upper_bound = oversample_center + (self.patch_size/2) + 1
-        oversample_patch_lower_bound = oversample_center - (self.patch_size/2 - 1)
-        oversample_patch_bound = np.concatenate((oversample_patch_lower_bound.reshape(-1,1),oversample_patch_upper_bound.reshape(-1,1)), axis = 1).astype(int)
-
-        oversample_patch_images = images[:, oversample_patch_bound[0][0] : oversample_patch_bound[0][1],
-                                          oversample_patch_bound[1][0] : oversample_patch_bound[1][1],
-                                          oversample_patch_bound[2][0] : oversample_patch_bound[2][1]]
-        oversample_patch_seg = seg[oversample_patch_bound[0][0] : oversample_patch_bound[0][1],
-                                          oversample_patch_bound[1][0] : oversample_patch_bound[1][1],
-                                          oversample_patch_bound[2][0] : oversample_patch_bound[2][1]]
-        
-        return np.expand_dims(oversample_patch_images , axis = 0), np.expand_dims(oversample_patch_seg , axis = 0)
-    
-    def get_normal_patch(self, images, seg):
-        if not isinstance(images, np.ndarray):
-            images = images.numpy()
-
-        if not isinstance(seg, np.ndarray):
-            seg = seg.numpy()
-
-        shape_to_index = np.array(images[0].shape) - 1 
-        normal_center = np.random.randint(low = self.patch_size/2 - 1, high = shape_to_index - (self.patch_size/2) + 1 )
-        normal_patch_upper_bound = normal_center + (self.patch_size/2) + 1
-        normal_patch_lower_bound = normal_center - (self.patch_size/2 - 1)
-        normal_patch_bound = np.concatenate((normal_patch_lower_bound.reshape(-1,1),normal_patch_upper_bound.reshape(-1,1)), axis = 1).astype(int)
-        normal_patch_images = images[:, normal_patch_bound[0][0] : normal_patch_bound[0][1],
-                                          normal_patch_bound[1][0] : normal_patch_bound[1][1],
-                                          normal_patch_bound[2][0] : normal_patch_bound[2][1]]
-        normal_patch_seg = seg[normal_patch_bound[0][0] : normal_patch_bound[0][1],
-                                          normal_patch_bound[1][0] : normal_patch_bound[1][1],
-                                          normal_patch_bound[2][0] : normal_patch_bound[2][1]]
-        
-        return np.expand_dims(normal_patch_images , axis = 0), np.expand_dims(normal_patch_seg , axis = 0)
-
-    
-    def pad_image_seg(self, images, seg): #patch size보다 전체 이미지 크기가 작을 경우 padding을 진행
-        if isinstance(images, np.ndarray):
-            images = torch.tensor(images.copy())
-        if isinstance(seg, np.ndarray):
-            seg = torch.tensor(seg.copy())
-        image_shape = np.array(images[0].shape)
-        if np.any(image_shape < self.patch_size):
-            odd_pad = ((self.patch_size - image_shape) % 2 != 0).astype(int)
-            even_pad = np.repeat(np.clip(((self.patch_size - image_shape)/2).astype(int), 0, np.inf), 2)
-            for i in range(len(odd_pad)):
-                even_pad[i*2] += odd_pad[i]
-            even_pad = tuple(even_pad[::-1].astype(int).copy())
-            images = F.pad(images, even_pad, "constant", 0 )
-            seg = F.pad(seg, even_pad, "constant", 0 )
-
-        return images, seg
-
-    def __getitem__(self, idx):
-        info_file = open(os.path.join(self.root_dir,self.info_name[idx]), 'rb')
-        info_data = pickle.load(info_file)
-        info_file.close()
-        data = np.load(os.path.join(self.root_dir, self.image_name[idx]))
-        
-
-        x = data['x']
-        y = data['y']
-        if len(x.shape) == 3 and self.dim == '3d':
-            #modality가 1개인 경우
-            x = np.expand_dims(x, axis = 0)
-        elif len(x.shape) == 2 and self.dim == '2d':
-            x = np.expand_dims(x, axis = 0)
-
-        if self.correct_direction:
-            for i in range(len(x)):
-                if i == 0:
-                    result = set_direction(x[i], info_data['direction']).unsqueeze(0)
-                else:
-                    result = torch.vstack((result, set_direction(x[i], info_data['direction']).unsqueeze(0)))
-            x = result 
-            if self.mode == 'train' :
-                y = set_direction(y, info_data['direction'])
-
-        if self.normalizer:
-            x = self.normalizer(x)
-        
-        
-        if self.resample != None:
-            if self.mode == 'train' :
-                if isinstance(y, np.ndarray):
-                    y = torch.tensor(y.copy())
-                result = self.resample(torch.vstack((x, y.unsqueeze(0))), info_data)
-                x = result[:-1]
-                y = result[-1].squeeze(0)
-            
-            else:
-                x = self.resample(x, info_data)
-        
-        x, y = self.pad_image_seg(x, y)
-        if self.batch_size == 1 :
-            result_images, result_seg = self.get_normal_patch(x, y)
-
-
-        for i_b in range(self.batch_size//2):
-            oversample_images, oversample_seg = self.get_oversample_patch(x, y)
-            normal_images, normal_seg = self.get_normal_patch(x, y)
-
-            if i_b == 0:
-                result_images = np.concatenate((normal_images, oversample_images), axis = 0) #bs, n, x, y, z
-                result_seg = np.concatenate((normal_seg, oversample_seg), axis = 0) #bs, x, y, z
-            
-            else:
-                result_images = np.concatenate((result_images, oversample_images), axis = 0)
-                result_seg = np.concatenate((result_seg, oversample_seg), axis = 0)
-                result_images = np.concatenate((result_images, normal_images), axis = 0)
-                result_seg = np.concatenate((result_seg, normal_seg), axis = 0)
-
-
-        if isinstance(result_images, np.ndarray):
-            result_images = torch.tensor(result_images)
-        
-        if isinstance(result_seg, np.ndarray):
-            result_seg = torch.tensor(result_seg)
-        
-        if result_images.device.index != self.device:
-            result_images = result_images.to(self.device)
-
-        if result_seg.device.index != self.device:
-            result_seg = result_seg.to(self.device)
-
-        if self.transform:
-            result_images, result_seg = self.transform(result_images.to(self.device), result_seg.to(self.device), info_data)
-        
-
-        return result_images.squeeze(0), result_seg.squeeze(0).long(), info_data
-
     
 
 """
