@@ -1,4 +1,3 @@
-
 import torch
 import torch.nn.functional as F
 import numpy as np
@@ -288,7 +287,7 @@ class Batch_Mirroring(object):
         self.y_prob = y_prob
         self.z_prob = z_prob
 
-    def get_mirror_axis(self):
+    def get_random_variables(self):
         do_mirror = np.random.uniform(0,1, size = 3)
         max_value = np.max(do_mirror)
         self.mirror_axis = []
@@ -309,6 +308,23 @@ class Batch_Mirroring(object):
         else:
             return images
 
+    
+class Batch_Random_Permute(object):
+    def __init__(self, permute_index = np.array([-1,-2,-3])):
+        self.permute_index = permute_index
+    
+    def get_random_variables(self):
+        self.next_permute = np.random.shuffle(self.permute_index)
+
+    def __call__(self, images):
+        if len(images.shape) == 5:
+            images = images.permute(0, 1, self.next_permute[0], self.next_permute[1], self.next_permute[2])
+        
+        elif len(images.shape) == 4:
+            images = images.permute(0, self.next_permute[0], self.next_permute[1], self.next_permute[2])
+
+        return images
+
 class Batch_Low_Resolution(object):
     def __init__(self, prob = 0.5):
         self.prob_per_modality = 0.5
