@@ -233,12 +233,16 @@ class Get_target_spacing(object):
 
 
 class ResamplingV2(object):
-    def __init__(self, anisotropy_axis_index = [], target_spacing = [1.0, 1.0, 1.0], random = False, device = None, spacing_order = [-3, -2, -1]):
+    def __init__(self, anisotropy_axis_index = [], target_spacing = [1.0, 1.0, 1.0], random = False, shape_print = False,
+                 device = None, spacing_order = [-3, -2, -1], do_check = False, check_threshold = 120):
         self.device = device
         self.anisotropy_axis_index = self.new_anisotropy_axis(anisotropy_axis_index)
         self.target_spacing = np.array(target_spacing)
         self.random = random
         self.spacing_order = spacing_order
+        self.do_check = do_check
+        self.check_threshold = check_threshold
+        self.shape_print = shape_print
     
     def new_anisotropy_axis(self, array):
         for i in range(len(array)):
@@ -248,6 +252,11 @@ class ResamplingV2(object):
                 array[i] += 1
         return array
 
+    def correct_dims(self, shape):
+        shape = np.array(shape)
+        if np.any(shape) < self.check_threshold:
+            shape[np.where(shape < self.check_threshold)] = np.max(shape) // 2
+        return tuple(shape)
 
     def __call__(self, img, info_data, seg = None):
         if isinstance(img, np.ndarray):
@@ -268,10 +277,15 @@ class ResamplingV2(object):
         if self.random:
             self.target_spacing = original_spacing * np.random.uniform(0.20, 5.0, size = np.array(original_spacing).shape)
         new_shape = list((original_spacing/self.target_spacing * np.array([img.shape[self.spacing_order[0]], img.shape[self.spacing_order[1]], img.shape[self.spacing_order[2]]])).astype(int))
+
+        if self.do_check:
+            new_shape = self.correct_dims(new_shape)
         
         img = F.interpolate(img.unsqueeze(0), new_shape, mode = 'trilinear').squeeze(0)
         
         if seg != None:
             seg = F.interpolate(seg.unsqueeze(0).unsqueeze(0), new_shape, mode = 'nearest').squeeze(0).squeeze(0)
 
+        if self.shape_print:
+            print("img shape : ", img.shape, "seg shape : ", seg.shape)
         return img, seg
