@@ -150,19 +150,19 @@ class Trainer(object):
         for i in range(len(self.losses)):
             loss = self.losses[i] #여러 Loss들에 대해
             temp = loss(output, target).contiguous() * torch.tensor(self.regulizers[i]).float().to(output.device.index)
-            for _ in range(len(temp.shape)-1):
-                temp = temp.mean(-1)
-            if is_val:
-                writer.add_scalar('Iteration\Val_Loss_'+ str(type(loss)), temp[0], epoch) #(batch, -1) 로 나오게끔 resize
-            else:
-                writer.add_scalar('Iteration\Train_Loss_'+ str(type(loss)), temp[0], epoch) #(batch, -1) 로 나오게끔 resize
-            if self.is_deep_supervision == True:
-                temp = temp.view(batch_size, deep_supervision_size, -1)
             if i == 0:
                 losses = temp
             else:
                 losses += temp
-        
+
+            #for _ in range(len(temp.shape)-1):
+            #    temp = temp.mean(-1)
+           
+            if is_val:
+                writer.add_scalar('Iteration\Val_Loss_'+ str(type(loss)), temp.mean().item(), epoch) #(batch, -1) 로 나오게끔 resize
+            else:
+                writer.add_scalar('Iteration\Train_Loss_'+ str(type(loss)), temp.mean().item(), epoch) #(batch, -1) 로 나오게끔 resize
+                    
         if self.is_deep_supervision == True:
             result = (losses * weight).mean()
             
